@@ -1,6 +1,6 @@
 from typing import Union, List
 import requests
-from distutils import version
+from packaging import version
 
 from .api import API
 from .const import (
@@ -87,7 +87,9 @@ class Powerwall:
         return assert_attribute(self._api.get_system_status_soe(), "percentage", "soe")
 
     def get_energy(self) -> int:
-        return assert_attribute(self._api.get_system_status(), "nominal_energy_remaining", "system_status")
+        return assert_attribute(
+            self._api.get_system_status(), "nominal_energy_remaining", "system_status"
+        )
 
     def get_sitemaster(self) -> SiteMaster:
         return SiteMaster(self._api.get_sitemaster())
@@ -104,10 +106,14 @@ class Powerwall:
         return GridStatus(status)
 
     def get_capacity(self) -> float:
-        return assert_attribute(self._api.get_system_status(), "nominal_full_pack_energy", "system_status")
+        return assert_attribute(
+            self._api.get_system_status(), "nominal_full_pack_energy", "system_status"
+        )
 
     def get_batteries(self) -> List[Battery]:
-        batteries = assert_attribute(self._api.get_system_status(), "battery_blocks", "system_status")
+        batteries = assert_attribute(
+            self._api.get_system_status(), "battery_blocks", "system_status"
+        )
         return [Battery(battery) for battery in batteries]
 
     def is_grid_services_active(self) -> bool:
@@ -129,7 +135,7 @@ class Powerwall:
 
     def get_device_type(self) -> DeviceType:
         """Returns the device type of the powerwall"""
-        if self._pin_version is None or self._pin_version >= version.LooseVersion(
+        if self._pin_version is None or self._pin_version >= version.Version(
             "1.46.0"
         ):
             return self.get_status().device_type
@@ -149,6 +155,10 @@ class Powerwall:
             for powerwall in powerwalls
         ]
 
+    def get_gateway_din(self) -> str:
+        """Return the gateway din."""
+        return assert_attribute(self._api.get_powerwalls(), "gateway_din", "powerwalls")
+
     def get_operation_mode(self) -> OperationMode:
         operation_mode = assert_attribute(
             self._api.get_operation(), "real_mode", "operation"
@@ -167,7 +177,8 @@ class Powerwall:
         return assert_attribute(self._api.get_config(), "vin", "config")
 
     def get_version(self) -> str:
-        return assert_attribute(self._api.get_status(), "version", "status")
+        version_str = assert_attribute(self._api.get_status(), "version", "status")
+        return version_str.split(' ')[0] # newer versions include a sha trailer '21.44.1 c58c2df3'
 
     def detect_and_pin_version(self) -> str:
         self.pin_version(self.get_version())
@@ -177,7 +188,7 @@ class Powerwall:
         if isinstance(vers, version.Version):
             self._pin_version = vers
         else:
-            self._pin_version = version.LooseVersion(vers)
+            self._pin_version = version.Version(vers)
 
     def get_pinned_version(self) -> version.Version:
         return self._pin_version
